@@ -7,8 +7,12 @@ from tempfile import NamedTemporaryFile
 
 from pipenv import environments, exceptions
 from pipenv.patched.pip._internal.exceptions import PipError
-from pipenv.patched.pip._vendor import rich
 from pipenv.routines.lock import do_lock
+from pipenv.utils import console, err, fileutils
+from pipenv.utils.dependencies import (
+    expansive_install_req_from_line,
+    get_lockfile_section_using_pipfile_category,
+)
 from pipenv.utils.indexes import get_source_list
 from pipenv.utils.internet import download_file, is_valid_url
 from pipenv.utils.pip import (
@@ -18,27 +22,20 @@ from pipenv.utils.pip import (
 from pipenv.utils.pipfile import ensure_pipfile
 from pipenv.utils.project import ensure_project
 from pipenv.utils.requirements import add_index_to_pipfile, import_requirements
+from pipenv.utils.shell import temp_environ
 from pipenv.utils.virtualenv import cleanup_virtualenv, do_create_virtualenv
-from pipenv.vendor import click
-from pipenv.vendor.requirementslib import fileutils
-from pipenv.vendor.requirementslib.models.requirements import Requirement
-from pipenv.vendor.requirementslib.utils import temp_environ
-
-console = rich.console.Console()
-err = rich.console.Console(stderr=True)
 
 
 def do_install(
     project,
     packages=False,
     editable_packages=False,
-    index_url=False,
+    index=False,
     dev=False,
     python=False,
     pypi_mirror=None,
     system=False,
     ignore_pipfile=False,
-    skip_lock=False,
     requirementstxt=False,
     pre=False,
     deploy=False,
@@ -67,12 +64,13 @@ def do_install(
         skip_requirements=skip_requirements,
         pypi_mirror=pypi_mirror,
         site_packages=site_packages,
+        categories=categories,
     )
     # Don't attempt to install develop and default packages if Pipfile is missing
     if not project.pipfile_exists and not (package_args or dev):
         if not (ignore_pipfile or deploy):
             raise exceptions.PipfileNotFound(project.path_to("Pipfile"))
-        elif ((skip_lock and deploy) or ignore_pipfile) and not project.lockfile_exists:
+        elif ignore_pipfile and not project.lockfile_exists:
             raise exceptions.LockfileNotFound(project.path_to("Pipfile.lock"))
     # Load the --pre settings from the Pipfile.
     if not pre:
@@ -97,10 +95,9 @@ def do_install(
         os.environ["PIPENV_USE_SYSTEM"] = "1"
     # Check if the file is remote or not
     if remote:
-        click.secho(
+        err.print(
             "Remote requirements file provided! Downloading...",
-            bold=True,
-            err=True,
+            style="bold",
         )
         fd = NamedTemporaryFile(
             prefix="pipenv-", suffix="-requirement.txt", dir=requirements_directory
@@ -113,33 +110,32 @@ def do_install(
         except OSError:
             fd.close()
             os.unlink(temp_reqs)
-            click.secho(
+            err.print(
                 f"Unable to find requirements file at {requirements_url}.",
-                fg="red",
-                err=True,
+                style="red",
             )
             sys.exit(1)
         finally:
             fd.close()
         # Replace the url with the temporary requirements file
         requirementstxt = temp_reqs
-        remote = True
     if requirementstxt:
         error, traceback = None, None
-        click.secho(
+        err.print(
             "Requirements file provided! Importing into Pipfile...",
-            bold=True,
-            err=True,
+            style="bold",
         )
         try:
-            import_requirements(project, r=project.path_to(requirementstxt), dev=dev)
+            import_requirements(
+                project,
+                r=project.path_to(requirementstxt),
+                dev=dev,
+                categories=categories,
+            )
         except (UnicodeDecodeError, PipError) as e:
             # Don't print the temp file path if remote since it will be deleted.
-            req_path = requirements_url if remote else project.path_to(requirementstxt)
-            error = (
-                "Unexpected syntax in {}. Are you sure this is a "
-                "requirements.txt style file?".format(req_path)
-            )
+            req_path = project.path_to(requirementstxt)
+            error = f"Unexpected syntax in {req_path}. Are you sure this is a requirements.txt style file?"
             traceback = e
         except AssertionError as e:
             error = (
@@ -148,13 +144,9 @@ def do_install(
             )
             traceback = e
         finally:
-            # If requirements file was provided by remote url delete the temporary file
-            if remote:
-                fd.close()  # Close for windows to allow file cleanup.
-                os.remove(temp_reqs)
             if error and traceback:
-                click.secho(error, fg="red")
-                click.secho(str(traceback), fg="yellow", err=True)
+                console.print(error, sytle="red")
+                err.print(str(traceback), style="yellow")
                 sys.exit(1)
 
     # Allow more than one package to be provided.
@@ -173,7 +165,6 @@ def do_install(
             allow_global=system,
             ignore_pipfile=ignore_pipfile,
             system=system,
-            skip_lock=skip_lock,
             deploy=deploy,
             pre=pre,
             requirements_dir=requirements_directory,
@@ -184,8 +175,6 @@ def do_install(
 
     # This is for if the user passed in dependencies, then we want to make sure we
     else:
-        from pipenv.vendor.requirementslib.models.requirements import Requirement
-
         # make a tuple of (display_name, entry)
         pkg_list = packages + [f"-e {pkg}" for pkg in editable_packages]
         if not system and not project.virtualenv_exists:
@@ -197,16 +186,14 @@ def do_install(
                 requirements_dir=requirements_directory,
                 deploy=deploy,
                 pypi_mirror=pypi_mirror,
-                skip_lock=skip_lock,
                 extra_pip_args=extra_pip_args,
                 categories=categories,
             )
 
         for pkg_line in pkg_list:
-            click.secho(
+            console.print(
                 f"Installing {pkg_line}...",
-                fg="green",
-                bold=True,
+                style="bold green",
             )
             # pip install:
             with temp_environ(), console.status(
@@ -216,11 +203,13 @@ def do_install(
                     os.environ["PIP_USER"] = "0"
                     if "PYTHONHOME" in os.environ:
                         del os.environ["PYTHONHOME"]
-                st.console.print(f"Resolving {pkg_line}...")
+                st.console.print(f"Resolving {pkg_line}...", markup=False)
                 try:
-                    pkg_requirement = Requirement.from_line(pkg_line)
+                    pkg_requirement = expansive_install_req_from_line(
+                        pkg_line, expand_env=True
+                    )
                 except ValueError as e:
-                    err.print("{}: {}".format(click.style("WARNING", fg="red"), e))
+                    err.print(f"[red]WARNING[/red]: {e}")
                     err.print(
                         environments.PIPENV_SPINNER_FAIL_TEXT.format(
                             "Installation Failed"
@@ -228,21 +217,6 @@ def do_install(
                     )
                     sys.exit(1)
                 st.update(f"Installing {pkg_requirement.name}...")
-                # Warn if --editable wasn't passed.
-                if (
-                    pkg_requirement.is_vcs
-                    and not pkg_requirement.editable
-                    and not project.s.PIPENV_RESOLVE_VCS
-                ):
-                    err.print(
-                        "{}: You installed a VCS dependency in non-editable mode. "
-                        "This will work fine, but sub-dependencies will not be resolved by {}."
-                        "\n  To enable this sub-dependency functionality, specify that this dependency is editable."
-                        "".format(
-                            click.style("Warning", fg="red", bold=True),
-                            click.style("$ pipenv lock", fg="yellow"),
-                        )
-                    )
                 if categories:
                     pipfile_sections = ""
                     for c in categories:
@@ -251,34 +225,42 @@ def do_install(
                     pipfile_sections = "[dev-packages]"
                 else:
                     pipfile_sections = "[packages]"
-                st.console.print(
-                    f"[bold]Adding [green]{pkg_requirement.name}[/green][/bold] to Pipfile's [yellow]\\{pipfile_sections}[/yellow] ..."
-                )
                 # Add the package to the Pipfile.
-                if index_url:
-                    index_name = add_index_to_pipfile(project, index_url)
-                    pkg_requirement.index = index_name
+                if index:
+                    source = project.get_index_by_name(index)
+                    default_index = project.get_default_index()["name"]
+                    if not source:
+                        index_name = add_index_to_pipfile(project, index)
+                        if index_name != default_index:
+                            pkg_requirement.index = index_name
+                    elif source["name"] != default_index:
+                        pkg_requirement.index = source["name"]
                 try:
                     if categories:
                         for category in categories:
-                            added, cat = project.add_package_to_pipfile(
-                                pkg_requirement, dev, category
+                            added, cat, normalized_name = project.add_package_to_pipfile(
+                                pkg_requirement, pkg_line, dev, category
                             )
                             if added:
-                                new_packages.append((pkg_requirement.name, cat))
+                                new_packages.append((normalized_name, cat))
+                                st.console.print(
+                                    f"[bold]Added [green]{normalized_name}[/green][/bold] to Pipfile's "
+                                    f"[yellow]\\{pipfile_sections}[/yellow] ..."
+                                )
                     else:
-                        added, cat = project.add_package_to_pipfile(pkg_requirement, dev)
+                        added, cat, normalized_name = project.add_package_to_pipfile(
+                            pkg_requirement, pkg_line, dev
+                        )
                         if added:
-                            new_packages.append((pkg_requirement.name, cat))
+                            new_packages.append((normalized_name, cat))
+                            st.console.print(
+                                f"[bold]Added [green]{normalized_name}[/green][/bold] to Pipfile's "
+                                f"[yellow]\\{pipfile_sections}[/yellow] ..."
+                            )
                 except ValueError:
                     import traceback
 
-                    err.print(
-                        "{} {}".format(
-                            click.style("Error:", fg="red", bold=True),
-                            traceback.format_exc(),
-                        )
-                    )
+                    err.print(f"[bold][red]Error:[/red][/bold] {traceback.format_exc()}")
                     err.print(
                         environments.PIPENV_SPINNER_FAIL_TEXT.format(
                             "Failed adding package to Pipfile"
@@ -300,15 +282,14 @@ def do_install(
                 requirements_dir=requirements_directory,
                 deploy=deploy,
                 pypi_mirror=pypi_mirror,
-                skip_lock=skip_lock,
                 extra_pip_args=extra_pip_args,
                 categories=categories,
             )
-        except RuntimeError:
+        except Exception as e:
             # If we fail to install, remove the package from the Pipfile.
             for pkg_name, category in new_packages:
                 project.remove_package_from_pipfile(pkg_name, category)
-            sys.exit(1)
+            raise e
     sys.exit(0)
 
 
@@ -363,7 +344,7 @@ def do_sync(
         categories=categories,
     )
     if not bare:
-        click.echo(click.style("All dependencies are now up-to-date!", fg="green"))
+        console.print("[green]All dependencies are now up-to-date![/green]")
 
 
 def do_install_dependencies(
@@ -373,7 +354,6 @@ def do_install_dependencies(
     bare=False,
     allow_global=False,
     ignore_hashes=False,
-    skip_lock=False,
     requirements_dir=None,
     pypi_mirror=None,
     extra_pip_args=None,
@@ -392,90 +372,48 @@ def do_install_dependencies(
         else:
             categories = ["packages"]
 
-    lockfile = None
-    pipfile = None
     for category in categories:
-        # Load the lockfile if it exists, or if dev_only is being used.
-        if skip_lock:
-            if not bare:
-                click.secho("Installing dependencies from Pipfile...", bold=True)
-            pipfile = project.get_pipfile_section(category)
-        else:
-            lockfile = project.get_or_create_lockfile(categories=categories)
-            if not bare:
-                click.secho(
-                    "Installing dependencies from Pipfile.lock ({})...".format(
-                        lockfile["_meta"].get("hash", {}).get("sha256")[-6:]
-                    ),
-                    bold=True,
-                )
-        dev = dev or dev_only
-        if lockfile:
-            deps_list = list(
-                lockfile.get_requirements(dev=dev, only=dev_only, categories=[category])
+        lockfile = project.get_or_create_lockfile(categories=categories)
+        if not bare:
+            console.print(
+                f"Installing dependencies from Pipfile.lock "
+                f"({lockfile['_meta'].get('hash', {}).get('sha256')[-6:]})...",
+                style="bold",
             )
-        else:
-            deps_list = []
-            for req_name, specifier in pipfile.items():
-                deps_list.append(Requirement.from_pipfile(req_name, specifier))
-        failed_deps_queue = queue.Queue()
-        if skip_lock:
-            ignore_hashes = True
-        editable_or_vcs_deps = [dep for dep in deps_list if (dep.editable or dep.vcs)]
-        normal_deps = [dep for dep in deps_list if not (dep.editable or dep.vcs)]
+        dev = dev or dev_only
+        deps_list = list(
+            lockfile.get_requirements(dev=dev, only=dev_only, categories=[category])
+        )
+        editable_or_vcs_deps = [
+            (dep, pip_line) for dep, pip_line in deps_list if (dep.link and dep.editable)
+        ]
+        normal_deps = [
+            (dep, pip_line)
+            for dep, pip_line in deps_list
+            if not (dep.link and dep.editable)
+        ]
+
         install_kwargs = {
-            "no_deps": not skip_lock,
+            "no_deps": True,
             "ignore_hashes": ignore_hashes,
             "allow_global": allow_global,
             "pypi_mirror": pypi_mirror,
             "sequential_deps": editable_or_vcs_deps,
             "extra_pip_args": extra_pip_args,
         }
-
+        lockfile_category = get_lockfile_section_using_pipfile_category(category)
+        lockfile_section = lockfile[lockfile_category]
         batch_install(
             project,
             normal_deps,
+            lockfile_section,
             procs,
-            failed_deps_queue,
             requirements_dir,
             **install_kwargs,
         )
 
         if not procs.empty():
-            _cleanup_procs(project, procs, failed_deps_queue)
-
-        # Iterate over the hopefully-poorly-packaged dependencies...
-        if not failed_deps_queue.empty():
-            click.secho("Installing initially failed dependencies...", bold=True)
-            retry_list = []
-            while not failed_deps_queue.empty():
-                failed_dep = failed_deps_queue.get()
-                retry_list.append(failed_dep)
-            install_kwargs.update({"retry": False})
-            batch_install(
-                project,
-                retry_list,
-                procs,
-                failed_deps_queue,
-                requirements_dir,
-                **install_kwargs,
-            )
-        if not procs.empty():
-            _cleanup_procs(project, procs, failed_deps_queue, retry=False)
-        if not failed_deps_queue.empty():
-            failed_list = []
-            while not failed_deps_queue.empty():
-                failed_dep = failed_deps_queue.get()
-                failed_list.append(failed_dep)
-            click.echo(
-                click.style(
-                    f"Failed to install some dependency or packages.  "
-                    f"The following have failed installation and attempted retry: {failed_list}",
-                    fg="red",
-                ),
-                err=True,
-            )
-            sys.exit(1)
+            _cleanup_procs(project, procs)
 
 
 def batch_install_iteration(
@@ -483,33 +421,12 @@ def batch_install_iteration(
     deps_to_install,
     sources,
     procs,
-    failed_deps_queue,
     requirements_dir,
     no_deps=True,
     ignore_hashes=False,
     allow_global=False,
-    retry=True,
     extra_pip_args=None,
 ):
-    from pipenv.vendor.requirementslib.models.utils import (
-        strip_extras_markers_from_requirement,
-    )
-
-    is_artifact = False
-    for dep in deps_to_install:
-        if dep.req.req:
-            dep.req.req = strip_extras_markers_from_requirement(dep.req.req)
-        if dep.markers:
-            dep.markers = str(strip_extras_markers_from_requirement(dep.get_markers))
-        # Install the module.
-        if dep.is_file_or_url and (
-            dep.is_direct_url
-            or any(dep.req.uri.endswith(ext) for ext in ["zip", "tar.gz"])
-        ):
-            is_artifact = True
-        elif dep.is_vcs:
-            is_artifact = True
-
     with temp_environ():
         if not allow_global:
             os.environ["PIP_USER"] = "0"
@@ -517,10 +434,6 @@ def batch_install_iteration(
                 del os.environ["PYTHONHOME"]
         if "GIT_CONFIG" in os.environ:
             del os.environ["GIT_CONFIG"]
-        use_pep517 = True
-        if not retry and not is_artifact:
-            use_pep517 = False
-
         cmds = pip_install_deps(
             project,
             deps=deps_to_install,
@@ -529,26 +442,25 @@ def batch_install_iteration(
             ignore_hashes=ignore_hashes,
             no_deps=no_deps,
             requirements_dir=requirements_dir,
-            use_pep517=use_pep517,
+            use_pep517=True,
             extra_pip_args=extra_pip_args,
         )
 
         for c in cmds:
             procs.put(c)
-            _cleanup_procs(project, procs, failed_deps_queue, retry=retry)
+            _cleanup_procs(project, procs)
 
 
 def batch_install(
     project,
     deps_list,
+    lockfile_section,
     procs,
-    failed_deps_queue,
     requirements_dir,
     no_deps=True,
     ignore_hashes=False,
     allow_global=False,
     pypi_mirror=None,
-    retry=True,
     sequential_deps=None,
     extra_pip_args=None,
 ):
@@ -557,7 +469,9 @@ def batch_install(
     deps_to_install = deps_list[:]
     deps_to_install.extend(sequential_deps)
     deps_to_install = [
-        dep for dep in deps_to_install if not project.environment.is_satisfied(dep)
+        (dep, pip_line)
+        for dep, pip_line in deps_to_install
+        if not project.environment.is_satisfied(dep)
     ]
     search_all_sources = project.settings.get("install_search_all_sources", False)
     sources = get_source_list(
@@ -568,27 +482,26 @@ def batch_install(
         pypi_mirror=pypi_mirror,
     )
     if search_all_sources:
+        dependencies = [pip_line for _, pip_line in deps_to_install]
         batch_install_iteration(
             project,
-            deps_to_install,
+            dependencies,
             sources,
             procs,
-            failed_deps_queue,
             requirements_dir,
             no_deps=no_deps,
             ignore_hashes=ignore_hashes,
             allow_global=allow_global,
-            retry=retry,
             extra_pip_args=extra_pip_args,
         )
     else:
         # Sort the dependencies out by index -- include editable/vcs in the default group
         deps_by_index = defaultdict(list)
-        for dependency in deps_to_install:
-            if dependency.index:
-                deps_by_index[dependency.index].append(dependency)
-            else:
-                deps_by_index[project.sources_default["name"]].append(dependency)
+        for dependency, pip_line in deps_to_install:
+            index = project.sources_default["name"]
+            if dependency.name and lockfile_section[dependency.name].get("index"):
+                index = lockfile_section[dependency.name]["index"]
+            deps_by_index[index].append(pip_line)
         # Treat each index as its own pip install phase
         for index_name, dependencies in deps_by_index.items():
             try:
@@ -598,24 +511,21 @@ def batch_install(
                     dependencies,
                     [install_source],
                     procs,
-                    failed_deps_queue,
                     requirements_dir,
                     no_deps=no_deps,
                     ignore_hashes=ignore_hashes,
                     allow_global=allow_global,
-                    retry=retry,
                     extra_pip_args=extra_pip_args,
                 )
             except StopIteration:
-                click.secho(
+                console.print(
                     f"Unable to find {index_name} in sources, please check dependencies: {dependencies}",
-                    fg="red",
-                    bold=True,
+                    style="bold red",
                 )
                 sys.exit(1)
 
 
-def _cleanup_procs(project, procs, failed_deps_queue, retry=True):
+def _cleanup_procs(project, procs):
     while not procs.empty():
         c = procs.get()
         try:
@@ -624,50 +534,17 @@ def _cleanup_procs(project, procs, failed_deps_queue, retry=True):
             out, err = c.stdout, c.stderr
         failed = c.returncode != 0
         if project.s.is_verbose():
-            click.secho(out.strip() or err.strip(), fg="yellow")
+            console.print(out.strip() or err.strip(), style="yellow")
         # The Installation failed...
         if failed:
+            # The Installation failed...
+            # We echo both c.stdout and c.stderr because pip returns error details on out.
+            err = err.strip().splitlines() if err else []
+            out = out.strip().splitlines() if out else []
+            err_lines = [line for message in [out, err] for line in message]
             deps = getattr(c, "deps", {}).copy()
-            for dep in deps:
-                # If there is a mismatch in installed locations or the install fails
-                # due to wrongful disabling of pep517, we should allow for
-                # additional passes at installation
-                if "does not match installed location" in err:
-                    project.environment.expand_egg_links()
-                    click.echo(
-                        "{}".format(
-                            click.style(
-                                "Failed initial installation: Failed to overwrite existing "
-                                "package, likely due to path aliasing. Expanding and trying "
-                                "again!",
-                                fg="yellow",
-                            )
-                        )
-                    )
-                    if dep:
-                        dep.use_pep517 = True
-                elif "Disabling PEP 517 processing is invalid" in err:
-                    if dep:
-                        dep.use_pep517 = True
-                elif not retry:
-                    # The Installation failed...
-                    # We echo both c.stdout and c.stderr because pip returns error details on out.
-                    err = err.strip().splitlines() if err else []
-                    out = out.strip().splitlines() if out else []
-                    err_lines = [line for message in [out, err] for line in message]
-                    # Return the subprocess' return code.
-                    raise exceptions.InstallError(deps, extra=err_lines)
-                else:
-                    # Alert the user.
-                    click.echo(
-                        "{} {}! Will try again.".format(
-                            click.style("An error occurred while installing", fg="red"),
-                            click.style(dep.as_line() if dep else "", fg="green"),
-                        ),
-                        err=True,
-                    )
-                # Save the Failed Dependency for later.
-                failed_deps_queue.put(dep)
+            # Return the subprocess' return code.
+            raise exceptions.InstallError(deps, extra=err_lines)
 
 
 def do_init(
@@ -676,7 +553,6 @@ def do_init(
     dev_only=False,
     allow_global=False,
     ignore_pipfile=False,
-    skip_lock=False,
     system=False,
     deploy=False,
     pre=False,
@@ -709,36 +585,31 @@ def do_init(
             suffix="-requirements", prefix="pipenv-"
         )
     # Write out the lockfile if it doesn't exist, but not if the Pipfile is being ignored
-    if (project.lockfile_exists and not ignore_pipfile) and not skip_lock:
+    if project.lockfile_exists and not ignore_pipfile:
         old_hash = project.get_lockfile_hash()
         new_hash = project.calculate_pipfile_hash()
         if new_hash != old_hash:
             if deploy:
-                click.secho(
-                    "Your Pipfile.lock (old_hash[-6:]) is out of date."
-                    " Expected: ({new_hash[-6:]}).",
-                    fg="red",
+                console.print(
+                    f"Your Pipfile.lock ({old_hash[-6:]}) is out of date.  Expected: ({new_hash[-6:]}).",
+                    style="red",
                 )
                 raise exceptions.DeployException
             if (system or allow_global) and not (project.s.PIPENV_VIRTUALENV):
-                click.secho(
-                    "Pipfile.lock ({}) out of date, but installation "
-                    "uses {} re-building lockfile must happen in "
-                    "isolation. Please rebuild lockfile in a virtualenv. "
-                    "Continuing anyway...".format(old_hash[-6:], "--system"),
-                    fg="yellow",
-                    err=True,
+                err.print(
+                    f"Pipfile.lock ({old_hash[-6:]}) out of date, but installation uses --system so"
+                    f"re-building lockfile must happen in isolation."
+                    f" Please rebuild lockfile in a virtualenv.  Continuing anyway...",
+                    style="yellow",
                 )
             else:
                 if old_hash:
                     msg = "Pipfile.lock ({0}) out of date, updating to ({1})..."
                 else:
                     msg = "Pipfile.lock is corrupt, replaced with ({1})..."
-                click.secho(
+                err.print(
                     msg.format(old_hash[-6:], new_hash[-6:]),
-                    fg="yellow",
-                    bold=True,
-                    err=True,
+                    style="bold yellow",
                 )
                 do_lock(
                     project,
@@ -749,7 +620,7 @@ def do_init(
                     categories=categories,
                 )
     # Write out the lockfile if it doesn't exist.
-    if not project.lockfile_exists and not skip_lock:
+    if not project.lockfile_exists:
         # Unless we're in a virtualenv not managed by pipenv, abort if we're
         # using the system's python.
         if (system or allow_global) and not (project.s.PIPENV_VIRTUALENV):
@@ -760,10 +631,9 @@ def do_init(
                 "See also: --deploy flag.",
             )
         else:
-            click.secho(
+            err.print(
                 "Pipfile.lock not found, creating...",
-                bold=True,
-                err=True,
+                style="bold",
             )
             do_lock(
                 project,
@@ -778,7 +648,6 @@ def do_init(
         dev=dev,
         dev_only=dev_only,
         allow_global=allow_global,
-        skip_lock=skip_lock,
         requirements_dir=requirements_dir,
         pypi_mirror=pypi_mirror,
         extra_pip_args=extra_pip_args,
@@ -787,11 +656,7 @@ def do_init(
 
     # Hint the user what to do to activate the virtualenv.
     if not allow_global and not deploy and "PIPENV_ACTIVE" not in os.environ:
-        click.echo(
-            "To activate this project's virtualenv, run {}.\n"
-            "Alternatively, run a command "
-            "inside the virtualenv with {}.".format(
-                click.style("pipenv shell", fg="yellow"),
-                click.style("pipenv run", fg="yellow"),
-            )
+        console.print(
+            "To activate this project's virtualenv, run [yellow]pipenv shell[/yellow].\n"
+            "Alternatively, run a command inside the virtualenv with [yellow]pipenv run[/yellow]."
         )
